Module binary

Module binary 

Binary object types (BI, BO, BV) Binary Object Types Implementation

This module implements the Binary Input, Binary Output, and Binary Value object types as defined in ASHRAE 135. These objects represent binary (two-state) values in BACnet.

Structs

BinaryInput
Binary Input object
BinaryOutput
Binary Output object
BinaryValue
Binary Value object

Enums

BinaryPV
Binary values enumeration
Polarity
Polarity enumeration