pub struct ProtocolServicesSupported(/* private fields */);Expand description
Protocol services supported bitfield
Implementations
Sourceimpl ProtocolServicesSupported
impl ProtocolServicesSupported
pub const ACKNOWLEDGE_ALARM: Self
pub const CONFIRMED_COV_NOTIFICATION: Self
pub const CONFIRMED_EVENT_NOTIFICATION: Self
pub const GET_ALARM_SUMMARY: Self
pub const GET_ENROLLMENT_SUMMARY: Self
pub const SUBSCRIBE_COV: Self
pub const ATOMIC_READ_FILE: Self
pub const ATOMIC_WRITE_FILE: Self
pub const ADD_LIST_ELEMENT: Self
pub const REMOVE_LIST_ELEMENT: Self
pub const CREATE_OBJECT: Self
pub const DELETE_OBJECT: Self
pub const READ_PROPERTY: Self
pub const READ_PROPERTY_CONDITIONAL: Self
pub const READ_PROPERTY_MULTIPLE: Self
pub const WRITE_PROPERTY: Self
pub const WRITE_PROPERTY_MULTIPLE: Self
pub const DEVICE_COMMUNICATION_CONTROL: Self
pub const CONFIRMED_PRIVATE_TRANSFER: Self
pub const CONFIRMED_TEXT_MESSAGE: Self
pub const REINITIALIZE_DEVICE: Self
pub const VT_OPEN: Self
pub const VT_CLOSE: Self
pub const VT_DATA: Self
pub const AUTHENTICATE: Self
pub const REQUEST_KEY: Self
pub const I_AM: Self
pub const I_HAVE: Self
pub const UNCONFIRMED_COV_NOTIFICATION: Self
pub const UNCONFIRMED_EVENT_NOTIFICATION: Self
pub const UNCONFIRMED_PRIVATE_TRANSFER: Self
pub const UNCONFIRMED_TEXT_MESSAGE: Self
pub const TIME_SYNCHRONIZATION: Self
pub const WHO_HAS: Self
pub const WHO_IS: Self
pub const READ_RANGE: Self
pub const UTC_TIME_SYNCHRONIZATION: Self
pub const LIFE_SAFETY_OPERATION: Self
pub const SUBSCRIBE_COV_PROPERTY: Self
pub const GET_EVENT_INFORMATION: Self
pub const WRITE_GROUP: Self
pub const SUBSCRIBE_COV_PROPERTY_MULTIPLE: Self
pub const CONFIRMED_COV_NOTIFICATION_MULTIPLE: Self
pub const UNCONFIRMED_COV_NOTIFICATION_MULTIPLE: Self
pub const CONFIRMED_AUDIT_NOTIFICATION: Self
pub const AUDIT_LOG_QUERY: Self
pub const UNCONFIRMED_AUDIT_NOTIFICATION: Self
pub const WHO_AM_I: Self
pub const YOU_ARE: Self
pub const AUTH_REQUEST: Self
Sourceimpl ProtocolServicesSupported
impl ProtocolServicesSupported
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ProtocolServicesSupported
impl ProtocolServicesSupported
Sourcepub const fn iter(&self) -> Iter<ProtocolServicesSupported>
pub const fn iter(&self) -> Iter<ProtocolServicesSupported>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ProtocolServicesSupported>
pub const fn iter_names(&self) -> IterNames<ProtocolServicesSupported>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ProtocolServicesSupported
impl ProtocolServicesSupported
pub fn to_bool_vec(&self) -> Vec<bool>