Binary object types (BI, BO, BV) Binary Object Types Implementation
This module implements the Binary Input, Binary Output, and Binary Value object types as defined in ASHRAE 135. These objects represent binary (two-state) values in BACnet.
Structs
- Binary
Input - Binary Input object
- Binary
Output - Binary Output object
- Binary
Value - Binary Value object